@@ -1,5 +1,3 @@
-from adnar_scraper.utility.database_controller import DatabaseController
-import settings
 from adnar_scraper.utility.data_loader import DataLoader
 
 try :
