@@ -24,13 +24,28 @@ class SaveFileController:
 
         self.saving_version = 0
 
-    def save_train_data(self, x_data_list, image_x_data_list, y_data_list):
+    def save_train_data(self, x_data_list, image_x_data_list, y_data_list, classifier, prime_category=None, sub_category=None, category=None):
         print("=" * 50)
         print('Train data(X,Image_X,Y) saved')
 
-        DataLoader.save_pickle_data(data=x_data_list, file_path=self.base_path + 'x_data')
-        DataLoader.save_pickle_data(data=image_x_data_list, file_path=self.base_path + 'image_x_data')
-        DataLoader.save_pickle_data(data=y_data_list, file_path=self.base_path + 'y_data')
+        if classifier is 'category':
+            category_path = 'category' + '/'
+
+            DataLoader.create_if_folder_not_exists(path=self.base_path + category_path)
+
+            DataLoader.save_pickle_data(data=x_data_list, file_path=self.base_path + category_path + 'x_data')
+            DataLoader.save_pickle_data(data=image_x_data_list, file_path=self.base_path + category_path + 'image_x_data')
+            DataLoader.save_pickle_data(data=y_data_list, file_path=self.base_path + category_path + 'y_data')
+
+        elif classifier is 'attribute':
+            attribute_path = 'attribute' + '/' + prime_category + '/' + sub_category + '/' + category + '/'
+
+            DataLoader.create_if_folder_not_exists(path=self.base_path + attribute_path)
+
+            DataLoader.save_pickle_data(data=x_data_list, file_path=self.base_path + attribute_path + 'x_data')
+            DataLoader.save_pickle_data(data=image_x_data_list, file_path=self.base_path + attribute_path + 'image_x_data')
+            DataLoader.save_pickle_data(data=y_data_list, file_path=self.base_path + attribute_path + 'y_data')
+
 
     def save_text_vec_model(self, vectorizer, features):
         print("=" * 50)
